/* Basic algorithm idea:
    For any time t, let M(t) be the minions that would
    be happy in a room with temperature t.

    Let i be the minion that has the smallest u value, say u[i]
    we know some time must be <= u[i] to satisfy minion i.
    For any t < u[i] we have M(t) is a subset of M(u[i]),
    so might as well use temperature u[i].

    i.e. pick the smallest u[i] value among the minions,
    make a room with that temperature and put all minions in the
    room that this will satisfy, and repeat with the remaining minions
    until all minions are in a room.
*/


#include <iostream>
#include <algorithm> // for sorting

using namespace std;

struct minion {
    int l, u;
    // so sorting the minions places smaller u[i] values earlier
    bool operator<(const minion& rhs) const {
        return u < rhs.u;
    }
};

int main() {
    minion mn[100];
    int n;

    cin >> n;
    for (int i = 0; i < n; ++i) {
        cin >> mn[i].l >> mn[i].u;
    }

    sort(mn, mn+n);

    // prev should be < all l[i] values
    int num = 0, prev = -1;

    for (int i = 0; i < n; ++i) {
        // if we encounter a new minion not in a room, make a new room
        if (mn[i].l > prev) {
            ++num;
            prev = mn[i].u;
        }
    }

    cout << num << endl;

    return 0;
}
